====================================================================
``psyclone.domain.nemo.transformations.nemo_arrayaccess2loop_trans``
====================================================================

.. automodule:: psyclone.domain.nemo.transformations.nemo_arrayaccess2loop_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.transformations.nemo_arrayaccess2loop_trans


Classes
=======

- :py:class:`NemoArrayAccess2LoopTrans`:
  Provides a transformation to transform a constant index access to


.. autoclass:: NemoArrayAccess2LoopTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: NemoArrayAccess2LoopTrans
      :parts: 1
